This is an automated email from the ASF dual-hosted git repository.

garydgregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-compress.git


The following commit(s) were added to refs/heads/master by this push:
     new d91c1eefc Javadoc
d91c1eefc is described below

commit d91c1eefc06fa64513bceb0126e8f4173407cba2
Author: Gary Gregory <[email protected]>
AuthorDate: Mon Aug 10 15:39:19 2026 -0400

    Javadoc
---
 .../java/org/apache/commons/compress/CompressException.java | 13 ++++++++++++-
 1 file changed, 12 insertions(+), 1 deletion(-)

diff --git a/src/main/java/org/apache/commons/compress/CompressException.java 
b/src/main/java/org/apache/commons/compress/CompressException.java
index 955a3181e..cc185b00d 100644
--- a/src/main/java/org/apache/commons/compress/CompressException.java
+++ b/src/main/java/org/apache/commons/compress/CompressException.java
@@ -24,10 +24,21 @@
 import java.util.function.Supplier;
 
 import org.apache.commons.compress.archivers.ArchiveException;
+import org.apache.commons.compress.compressors.CompressorException;
 import org.apache.commons.lang3.function.Suppliers;
 
 /**
  * Signals that a Compress I/O exception of some sort has occurred.
interrupted I/O operations in Commons Compress.
+ * </p>
+ * <p>
+ * Note that we also have the following subclasses of {@link 
CompressException} that are more specific to the type of operation that failed:
+ * </p>
+ * <ul>
+ * <li>{@link ArchiveException} is used for exceptions specific to archive 
operations.</li>
+ * <li>{@link CompressorException} is used for exceptions specific to 
compression operations.</li>
+ * </ul>
  *
  * @since 1.28.0
  */
@@ -24,10 +24,21 @@
 
 /**
- * Signals that a Compress I/O exception of some sort has occurred.
+ * Signals that a Commons Compress I/O exception of some sort has occurred.
+ * <p>
+ * This class is the general class of exceptions produced by failed or 
interrupted I/O operations in Commons Compress.

Reply via email to